import 'server-only';
import { createTranslator, createIntl } from 'use-intl/dist/src/core';
import NextRequestStorage from './NextRequestStorage';
class NextIntlRequestStorage {
    constructor() {
        this.key = '__next-intl';
        this.storage = new NextRequestStorage(this.key);
    }
    initRequest(opts) {
        const translator = createTranslator({
            ...opts,
            messages: opts.messages
        });
        const intl = createIntl(opts);
        const now = opts.now || new Date();
        this.storage.set({ ...opts, translator, intl, now });
    }
    isInitialized() {
        return this.storage.get() != null;
    }
    getLocale() {
        return this.getInitializedStorage().locale;
    }
    getTranslator() {
        return this.getInitializedStorage().translator;
    }
    getIntl() {
        return this.getInitializedStorage().intl;
    }
    getNow() {
        return this.getInitializedStorage().now;
    }
    getTimeZone() {
        return this.getInitializedStorage().timeZone;
    }
    getInitializedStorage() {
        if (!this.isInitialized()) {
            throw new Error('`NextIntlServerProvider` was not initialized.');
        }
        return this.storage.get();
    }
}
// Provide a singleton-instance of the storage.
const instance = new NextIntlRequestStorage();
export default instance;
//# sourceMappingURL=NextIntlRequestStorage.js.map