import { requestAsyncStorage } from 'next/dist/client/components/request-async-storage';
/**
 * Returns the request-level storage of Next.js where typically headers
 * and cookies are stored. This is recreated for every request.
 *
 * This uses internal APIs of Next.js and may break in
 * the future, so we should really move away from this.
 */
export default class NextRequestStorage {
    constructor(key) {
        this.key = key;
    }
    set(value) {
        const storage = this.getStorage();
        storage[this.key] = value;
    }
    get() {
        const storage = this.getStorage();
        return storage[this.key];
    }
    getStorage() {
        const requestStore = requestAsyncStorage && 'getStore' in requestAsyncStorage
            ? requestAsyncStorage.getStore()
            : requestAsyncStorage;
        return requestStore;
    }
}
//# sourceMappingURL=NextRequestStorage.js.map